package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.AlarmInfo;
import com.zyc.system.service.IAlarmInfoService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 告警信息Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/AlarmInfoController")
public class AlarmInfoController extends BaseController
{
    @Autowired
    private IAlarmInfoService alarmInfoService;

    /**
     * 查询告警信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(AlarmInfo alarmInfo)
    {
        startPage();
        List<AlarmInfo> list = alarmInfoService.selectAlarmInfoList(alarmInfo);
        return getDataTable(list);
    }

    /**
     * 导出告警信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:info:export')")
    @Log(title = "告警信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AlarmInfo alarmInfo)
    {
        List<AlarmInfo> list = alarmInfoService.selectAlarmInfoList(alarmInfo);
        ExcelUtil<AlarmInfo> util = new ExcelUtil<AlarmInfo>(AlarmInfo.class);
        util.exportExcel(response, list, "告警信息数据");
    }

    /**
     * 获取告警信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:info:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(alarmInfoService.selectAlarmInfoById(id));
    }

    /**
     * 新增告警信息
     */
    @PreAuthorize("@ss.hasPermi('system:info:add')")
    @Log(title = "告警信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AlarmInfo alarmInfo)
    {
        return toAjax(alarmInfoService.insertAlarmInfo(alarmInfo));
    }

    /**
     * 修改告警信息
     */
    @PreAuthorize("@ss.hasPermi('system:info:edit')")
    @Log(title = "告警信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AlarmInfo alarmInfo)
    {
        return toAjax(alarmInfoService.updateAlarmInfo(alarmInfo));
    }

    /**
     * 删除告警信息
     */
    @PreAuthorize("@ss.hasPermi('system:info:remove')")
    @Log(title = "告警信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(alarmInfoService.deleteAlarmInfoByIds(ids));
    }
}
