package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.AmsApplicationGridServices;
import com.zyc.system.service.IAmsApplicationGridServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * AMS应用网格服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/AmsApplicationGridServicesController")
public class AmsApplicationGridServicesController extends BaseController
{
    @Autowired
    private IAmsApplicationGridServicesService amsApplicationGridServicesService;

    /**
     * 查询AMS应用网格服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(AmsApplicationGridServices amsApplicationGridServices)
    {
        startPage();
        List<AmsApplicationGridServices> list = amsApplicationGridServicesService.selectAmsApplicationGridServicesList(amsApplicationGridServices);
        return getDataTable(list);
    }

    /**
     * 导出AMS应用网格服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "AMS应用网格服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AmsApplicationGridServices amsApplicationGridServices)
    {
        List<AmsApplicationGridServices> list = amsApplicationGridServicesService.selectAmsApplicationGridServicesList(amsApplicationGridServices);
        ExcelUtil<AmsApplicationGridServices> util = new ExcelUtil<AmsApplicationGridServices>(AmsApplicationGridServices.class);
        util.exportExcel(response, list, "AMS应用网格服务数据");
    }

    /**
     * 获取AMS应用网格服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(amsApplicationGridServicesService.selectAmsApplicationGridServicesById(id));
    }

    /**
     * 新增AMS应用网格服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "AMS应用网格服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AmsApplicationGridServices amsApplicationGridServices)
    {
        return toAjax(amsApplicationGridServicesService.insertAmsApplicationGridServices(amsApplicationGridServices));
    }

    /**
     * 修改AMS应用网格服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "AMS应用网格服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AmsApplicationGridServices amsApplicationGridServices)
    {
        return toAjax(amsApplicationGridServicesService.updateAmsApplicationGridServices(amsApplicationGridServices));
    }

    /**
     * 删除AMS应用网格服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "AMS应用网格服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(amsApplicationGridServicesService.deleteAmsApplicationGridServicesByIds(ids));
    }
}
