package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.ContainerServices;
import com.zyc.system.service.IContainerServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 容器服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/ContainerServicesController")
public class ContainerServicesController extends BaseController
{
    @Autowired
    private IContainerServicesService containerServicesService;

    /**
     * 查询容器服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(ContainerServices containerServices)
    {
        startPage();
        List<ContainerServices> list = containerServicesService.selectContainerServicesList(containerServices);
        return getDataTable(list);
    }

    /**
     * 导出容器服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "容器服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ContainerServices containerServices)
    {
        List<ContainerServices> list = containerServicesService.selectContainerServicesList(containerServices);
        ExcelUtil<ContainerServices> util = new ExcelUtil<ContainerServices>(ContainerServices.class);
        util.exportExcel(response, list, "容器服务数据");
    }

    /**
     * 获取容器服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(containerServicesService.selectContainerServicesById(id));
    }

    /**
     * 新增容器服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "容器服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ContainerServices containerServices)
    {
        return toAjax(containerServicesService.insertContainerServices(containerServices));
    }

    /**
     * 修改容器服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "容器服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ContainerServices containerServices)
    {
        return toAjax(containerServicesService.updateContainerServices(containerServices));
    }

    /**
     * 删除容器服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "容器服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(containerServicesService.deleteContainerServicesByIds(ids));
    }
}
