package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.DamengDatabaseServices;
import com.zyc.system.service.IDamengDatabaseServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 达梦数据库服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/DamengDatabaseServicesController")
public class DamengDatabaseServicesController extends BaseController
{
    @Autowired
    private IDamengDatabaseServicesService damengDatabaseServicesService;

    /**
     * 查询达梦数据库服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(DamengDatabaseServices damengDatabaseServices)
    {
        startPage();
        List<DamengDatabaseServices> list = damengDatabaseServicesService.selectDamengDatabaseServicesList(damengDatabaseServices);
        return getDataTable(list);
    }

    /**
     * 导出达梦数据库服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "达梦数据库服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DamengDatabaseServices damengDatabaseServices)
    {
        List<DamengDatabaseServices> list = damengDatabaseServicesService.selectDamengDatabaseServicesList(damengDatabaseServices);
        ExcelUtil<DamengDatabaseServices> util = new ExcelUtil<DamengDatabaseServices>(DamengDatabaseServices.class);
        util.exportExcel(response, list, "达梦数据库服务数据");
    }

    /**
     * 获取达梦数据库服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(damengDatabaseServicesService.selectDamengDatabaseServicesById(id));
    }

    /**
     * 新增达梦数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "达梦数据库服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DamengDatabaseServices damengDatabaseServices)
    {
        return toAjax(damengDatabaseServicesService.insertDamengDatabaseServices(damengDatabaseServices));
    }

    /**
     * 修改达梦数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "达梦数据库服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DamengDatabaseServices damengDatabaseServices)
    {
        return toAjax(damengDatabaseServicesService.updateDamengDatabaseServices(damengDatabaseServices));
    }

    /**
     * 删除达梦数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "达梦数据库服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(damengDatabaseServicesService.deleteDamengDatabaseServicesByIds(ids));
    }
}
