package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.Devices;
import com.zyc.system.service.IDevicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 设备基本信息Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/DevicesController")
public class DevicesController extends BaseController
{
    @Autowired
    private IDevicesService devicesService;

    /**
     * 查询设备基本信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:devices:list')")
    @GetMapping("/list")
    public TableDataInfo list(Devices devices)
    {
        startPage();
        List<Devices> list = devicesService.selectDevicesList(devices);
        return getDataTable(list);
    }

    /**
     * 导出设备基本信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:devices:export')")
    @Log(title = "设备基本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Devices devices)
    {
        List<Devices> list = devicesService.selectDevicesList(devices);
        ExcelUtil<Devices> util = new ExcelUtil<Devices>(Devices.class);
        util.exportExcel(response, list, "设备基本信息数据");
    }

    /**
     * 获取设备基本信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:devices:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(devicesService.selectDevicesById(id));
    }

    /**
     * 新增设备基本信息
     */
    @PreAuthorize("@ss.hasPermi('system:devices:add')")
    @Log(title = "设备基本信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Devices devices)
    {
        return toAjax(devicesService.insertDevices(devices));
    }

    /**
     * 修改设备基本信息
     */
    @PreAuthorize("@ss.hasPermi('system:devices:edit')")
    @Log(title = "设备基本信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Devices devices)
    {
        return toAjax(devicesService.updateDevices(devices));
    }

    /**
     * 删除设备基本信息
     */
    @PreAuthorize("@ss.hasPermi('system:devices:remove')")
    @Log(title = "设备基本信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(devicesService.deleteDevicesByIds(ids));
    }
}
