package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.DisasterRecoveryServices;
import com.zyc.system.service.IDisasterRecoveryServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 灾备服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/DisasterRecoveryServicesController")
public class DisasterRecoveryServicesController extends BaseController
{
    @Autowired
    private IDisasterRecoveryServicesService disasterRecoveryServicesService;

    /**
     * 查询灾备服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(DisasterRecoveryServices disasterRecoveryServices)
    {
        startPage();
        List<DisasterRecoveryServices> list = disasterRecoveryServicesService.selectDisasterRecoveryServicesList(disasterRecoveryServices);
        return getDataTable(list);
    }

    /**
     * 导出灾备服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "灾备服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DisasterRecoveryServices disasterRecoveryServices)
    {
        List<DisasterRecoveryServices> list = disasterRecoveryServicesService.selectDisasterRecoveryServicesList(disasterRecoveryServices);
        ExcelUtil<DisasterRecoveryServices> util = new ExcelUtil<DisasterRecoveryServices>(DisasterRecoveryServices.class);
        util.exportExcel(response, list, "灾备服务数据");
    }

    /**
     * 获取灾备服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(disasterRecoveryServicesService.selectDisasterRecoveryServicesById(id));
    }

    /**
     * 新增灾备服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "灾备服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DisasterRecoveryServices disasterRecoveryServices)
    {
        return toAjax(disasterRecoveryServicesService.insertDisasterRecoveryServices(disasterRecoveryServices));
    }

    /**
     * 修改灾备服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "灾备服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DisasterRecoveryServices disasterRecoveryServices)
    {
        return toAjax(disasterRecoveryServicesService.updateDisasterRecoveryServices(disasterRecoveryServices));
    }

    /**
     * 删除灾备服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "灾备服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(disasterRecoveryServicesService.deleteDisasterRecoveryServicesByIds(ids));
    }
}
