package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.DistributedCacheServices;
import com.zyc.system.service.IDistributedCacheServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 分布式缓存服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/DistributedCacheServicesController")
public class DistributedCacheServicesController extends BaseController
{
    @Autowired
    private IDistributedCacheServicesService distributedCacheServicesService;

    /**
     * 查询分布式缓存服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(DistributedCacheServices distributedCacheServices)
    {
        startPage();
        List<DistributedCacheServices> list = distributedCacheServicesService.selectDistributedCacheServicesList(distributedCacheServices);
        return getDataTable(list);
    }

    /**
     * 导出分布式缓存服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "分布式缓存服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DistributedCacheServices distributedCacheServices)
    {
        List<DistributedCacheServices> list = distributedCacheServicesService.selectDistributedCacheServicesList(distributedCacheServices);
        ExcelUtil<DistributedCacheServices> util = new ExcelUtil<DistributedCacheServices>(DistributedCacheServices.class);
        util.exportExcel(response, list, "分布式缓存服务数据");
    }

    /**
     * 获取分布式缓存服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(distributedCacheServicesService.selectDistributedCacheServicesById(id));
    }

    /**
     * 新增分布式缓存服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "分布式缓存服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DistributedCacheServices distributedCacheServices)
    {
        return toAjax(distributedCacheServicesService.insertDistributedCacheServices(distributedCacheServices));
    }

    /**
     * 修改分布式缓存服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "分布式缓存服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DistributedCacheServices distributedCacheServices)
    {
        return toAjax(distributedCacheServicesService.updateDistributedCacheServices(distributedCacheServices));
    }

    /**
     * 删除分布式缓存服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "分布式缓存服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(distributedCacheServicesService.deleteDistributedCacheServicesByIds(ids));
    }
}
