package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.ElasticIpServices;
import com.zyc.system.service.IElasticIpServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 弹性IP服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/ElasticIpServicesController")
public class ElasticIpServicesController extends BaseController
{
    @Autowired
    private IElasticIpServicesService elasticIpServicesService;

    /**
     * 查询弹性IP服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(ElasticIpServices elasticIpServices)
    {
        startPage();
        List<ElasticIpServices> list = elasticIpServicesService.selectElasticIpServicesList(elasticIpServices);
        return getDataTable(list);
    }

    /**
     * 导出弹性IP服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "弹性IP服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ElasticIpServices elasticIpServices)
    {
        List<ElasticIpServices> list = elasticIpServicesService.selectElasticIpServicesList(elasticIpServices);
        ExcelUtil<ElasticIpServices> util = new ExcelUtil<ElasticIpServices>(ElasticIpServices.class);
        util.exportExcel(response, list, "弹性IP服务数据");
    }

    /**
     * 获取弹性IP服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(elasticIpServicesService.selectElasticIpServicesById(id));
    }

    /**
     * 新增弹性IP服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "弹性IP服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ElasticIpServices elasticIpServices)
    {
        return toAjax(elasticIpServicesService.insertElasticIpServices(elasticIpServices));
    }

    /**
     * 修改弹性IP服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "弹性IP服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ElasticIpServices elasticIpServices)
    {
        return toAjax(elasticIpServicesService.updateElasticIpServices(elasticIpServices));
    }

    /**
     * 删除弹性IP服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "弹性IP服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(elasticIpServicesService.deleteElasticIpServicesByIds(ids));
    }
}
