package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.FileStorageServices;
import com.zyc.system.service.IFileStorageServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 文件存储服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/FileStorageServicesController")
public class FileStorageServicesController extends BaseController
{
    @Autowired
    private IFileStorageServicesService fileStorageServicesService;

    /**
     * 查询文件存储服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(FileStorageServices fileStorageServices)
    {
        startPage();
        List<FileStorageServices> list = fileStorageServicesService.selectFileStorageServicesList(fileStorageServices);
        return getDataTable(list);
    }

    /**
     * 导出文件存储服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "文件存储服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FileStorageServices fileStorageServices)
    {
        List<FileStorageServices> list = fileStorageServicesService.selectFileStorageServicesList(fileStorageServices);
        ExcelUtil<FileStorageServices> util = new ExcelUtil<FileStorageServices>(FileStorageServices.class);
        util.exportExcel(response, list, "文件存储服务数据");
    }

    /**
     * 获取文件存储服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(fileStorageServicesService.selectFileStorageServicesById(id));
    }

    /**
     * 新增文件存储服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "文件存储服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FileStorageServices fileStorageServices)
    {
        return toAjax(fileStorageServicesService.insertFileStorageServices(fileStorageServices));
    }

    /**
     * 修改文件存储服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "文件存储服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FileStorageServices fileStorageServices)
    {
        return toAjax(fileStorageServicesService.updateFileStorageServices(fileStorageServices));
    }

    /**
     * 删除文件存储服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "文件存储服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(fileStorageServicesService.deleteFileStorageServicesByIds(ids));
    }
}
