package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.ImageServices;
import com.zyc.system.service.IImageServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 镜像服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/ImageServicesController")
public class ImageServicesController extends BaseController
{
    @Autowired
    private IImageServicesService imageServicesService;

    /**
     * 查询镜像服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(ImageServices imageServices)
    {
        startPage();
        List<ImageServices> list = imageServicesService.selectImageServicesList(imageServices);
        return getDataTable(list);
    }

    /**
     * 导出镜像服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "镜像服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ImageServices imageServices)
    {
        List<ImageServices> list = imageServicesService.selectImageServicesList(imageServices);
        ExcelUtil<ImageServices> util = new ExcelUtil<ImageServices>(ImageServices.class);
        util.exportExcel(response, list, "镜像服务数据");
    }

    /**
     * 获取镜像服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(imageServicesService.selectImageServicesById(id));
    }

    /**
     * 新增镜像服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "镜像服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ImageServices imageServices)
    {
        return toAjax(imageServicesService.insertImageServices(imageServices));
    }

    /**
     * 修改镜像服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "镜像服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ImageServices imageServices)
    {
        return toAjax(imageServicesService.updateImageServices(imageServices));
    }

    /**
     * 删除镜像服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "镜像服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(imageServicesService.deleteImageServicesByIds(ids));
    }
}
