package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.ObjectStorageServices;
import com.zyc.system.service.IObjectStorageServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 对象存储服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/ObjectStorageServicesController")
public class ObjectStorageServicesController extends BaseController
{
    @Autowired
    private IObjectStorageServicesService objectStorageServicesService;

    /**
     * 查询对象存储服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(ObjectStorageServices objectStorageServices)
    {
        startPage();
        List<ObjectStorageServices> list = objectStorageServicesService.selectObjectStorageServicesList(objectStorageServices);
        return getDataTable(list);
    }

    /**
     * 导出对象存储服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "对象存储服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ObjectStorageServices objectStorageServices)
    {
        List<ObjectStorageServices> list = objectStorageServicesService.selectObjectStorageServicesList(objectStorageServices);
        ExcelUtil<ObjectStorageServices> util = new ExcelUtil<ObjectStorageServices>(ObjectStorageServices.class);
        util.exportExcel(response, list, "对象存储服务数据");
    }

    /**
     * 获取对象存储服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(objectStorageServicesService.selectObjectStorageServicesById(id));
    }

    /**
     * 新增对象存储服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "对象存储服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ObjectStorageServices objectStorageServices)
    {
        return toAjax(objectStorageServicesService.insertObjectStorageServices(objectStorageServices));
    }

    /**
     * 修改对象存储服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "对象存储服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ObjectStorageServices objectStorageServices)
    {
        return toAjax(objectStorageServicesService.updateObjectStorageServices(objectStorageServices));
    }

    /**
     * 删除对象存储服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "对象存储服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(objectStorageServicesService.deleteObjectStorageServicesByIds(ids));
    }
}
