package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.PortOpening;
import com.zyc.system.service.IPortOpeningService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 端口开放Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/PortOpeningController")
public class PortOpeningController extends BaseController
{
    @Autowired
    private IPortOpeningService portOpeningService;

    /**
     * 查询端口开放列表
     */
    @PreAuthorize("@ss.hasPermi('system:opening:list')")
    @GetMapping("/list")
    public TableDataInfo list(PortOpening portOpening)
    {
        startPage();
        List<PortOpening> list = portOpeningService.selectPortOpeningList(portOpening);
        return getDataTable(list);
    }

    /**
     * 导出端口开放列表
     */
    @PreAuthorize("@ss.hasPermi('system:opening:export')")
    @Log(title = "端口开放", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PortOpening portOpening)
    {
        List<PortOpening> list = portOpeningService.selectPortOpeningList(portOpening);
        ExcelUtil<PortOpening> util = new ExcelUtil<PortOpening>(PortOpening.class);
        util.exportExcel(response, list, "端口开放数据");
    }

    /**
     * 获取端口开放详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:opening:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(portOpeningService.selectPortOpeningById(id));
    }

    /**
     * 新增端口开放
     */
    @PreAuthorize("@ss.hasPermi('system:opening:add')")
    @Log(title = "端口开放", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PortOpening portOpening)
    {
        return toAjax(portOpeningService.insertPortOpening(portOpening));
    }

    /**
     * 修改端口开放
     */
    @PreAuthorize("@ss.hasPermi('system:opening:edit')")
    @Log(title = "端口开放", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PortOpening portOpening)
    {
        return toAjax(portOpeningService.updatePortOpening(portOpening));
    }

    /**
     * 删除端口开放
     */
    @PreAuthorize("@ss.hasPermi('system:opening:remove')")
    @Log(title = "端口开放", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(portOpeningService.deletePortOpeningByIds(ids));
    }
}
