package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.RelationalDatabaseServices;
import com.zyc.system.service.IRelationalDatabaseServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 关系型数据库服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/RelationalDatabaseServicesController")
public class RelationalDatabaseServicesController extends BaseController
{
    @Autowired
    private IRelationalDatabaseServicesService relationalDatabaseServicesService;

    /**
     * 查询关系型数据库服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(RelationalDatabaseServices relationalDatabaseServices)
    {
        startPage();
        List<RelationalDatabaseServices> list = relationalDatabaseServicesService.selectRelationalDatabaseServicesList(relationalDatabaseServices);
        return getDataTable(list);
    }

    /**
     * 导出关系型数据库服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "关系型数据库服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RelationalDatabaseServices relationalDatabaseServices)
    {
        List<RelationalDatabaseServices> list = relationalDatabaseServicesService.selectRelationalDatabaseServicesList(relationalDatabaseServices);
        ExcelUtil<RelationalDatabaseServices> util = new ExcelUtil<RelationalDatabaseServices>(RelationalDatabaseServices.class);
        util.exportExcel(response, list, "关系型数据库服务数据");
    }

    /**
     * 获取关系型数据库服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(relationalDatabaseServicesService.selectRelationalDatabaseServicesById(id));
    }

    /**
     * 新增关系型数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "关系型数据库服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RelationalDatabaseServices relationalDatabaseServices)
    {
        return toAjax(relationalDatabaseServicesService.insertRelationalDatabaseServices(relationalDatabaseServices));
    }

    /**
     * 修改关系型数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "关系型数据库服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RelationalDatabaseServices relationalDatabaseServices)
    {
        return toAjax(relationalDatabaseServicesService.updateRelationalDatabaseServices(relationalDatabaseServices));
    }

    /**
     * 删除关系型数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "关系型数据库服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(relationalDatabaseServicesService.deleteRelationalDatabaseServicesByIds(ids));
    }
}
