package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.SecurityServices;
import com.zyc.system.service.ISecurityServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 安全服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/SecurityServicesController")
public class SecurityServicesController extends BaseController
{
    @Autowired
    private ISecurityServicesService securityServicesService;

    /**
     * 查询安全服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(SecurityServices securityServices)
    {
        startPage();
        List<SecurityServices> list = securityServicesService.selectSecurityServicesList(securityServices);
        return getDataTable(list);
    }

    /**
     * 导出安全服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "安全服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SecurityServices securityServices)
    {
        List<SecurityServices> list = securityServicesService.selectSecurityServicesList(securityServices);
        ExcelUtil<SecurityServices> util = new ExcelUtil<SecurityServices>(SecurityServices.class);
        util.exportExcel(response, list, "安全服务数据");
    }

    /**
     * 获取安全服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(securityServicesService.selectSecurityServicesById(id));
    }

    /**
     * 新增安全服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "安全服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SecurityServices securityServices)
    {
        return toAjax(securityServicesService.insertSecurityServices(securityServices));
    }

    /**
     * 修改安全服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "安全服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SecurityServices securityServices)
    {
        return toAjax(securityServicesService.updateSecurityServices(securityServices));
    }

    /**
     * 删除安全服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "安全服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(securityServicesService.deleteSecurityServicesByIds(ids));
    }
}
