package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.MicroservicesMapper;
import com.zyc.system.domain.Microservices;
import com.zyc.system.service.IMicroservicesService;

/**
 * 微服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class MicroservicesServiceImpl implements IMicroservicesService 
{
    @Autowired
    private MicroservicesMapper microservicesMapper;

    /**
     * 查询微服务
     * 
     * @param id 微服务主键
     * @return 微服务
     */
    @Override
    public Microservices selectMicroservicesById(Integer id)
    {
        return microservicesMapper.selectMicroservicesById(id);
    }

    /**
     * 查询微服务列表
     * 
     * @param microservices 微服务
     * @return 微服务
     */
    @Override
    public List<Microservices> selectMicroservicesList(Microservices microservices)
    {
        return microservicesMapper.selectMicroservicesList(microservices);
    }

    /**
     * 新增微服务
     * 
     * @param microservices 微服务
     * @return 结果
     */
    @Override
    public int insertMicroservices(Microservices microservices)
    {
        return microservicesMapper.insertMicroservices(microservices);
    }

    /**
     * 修改微服务
     * 
     * @param microservices 微服务
     * @return 结果
     */
    @Override
    public int updateMicroservices(Microservices microservices)
    {
        return microservicesMapper.updateMicroservices(microservices);
    }

    /**
     * 批量删除微服务
     * 
     * @param ids 需要删除的微服务主键
     * @return 结果
     */
    @Override
    public int deleteMicroservicesByIds(Integer[] ids)
    {
        return microservicesMapper.deleteMicroservicesByIds(ids);
    }

    /**
     * 删除微服务信息
     * 
     * @param id 微服务主键
     * @return 结果
     */
    @Override
    public int deleteMicroservicesById(Integer id)
    {
        return microservicesMapper.deleteMicroservicesById(id);
    }
}
