package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.VpnServicesMapper;
import com.zyc.system.domain.VpnServices;
import com.zyc.system.service.IVpnServicesService;

/**
 * 虚拟专用网络VPN服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class VpnServicesServiceImpl implements IVpnServicesService 
{
    @Autowired
    private VpnServicesMapper vpnServicesMapper;

    /**
     * 查询虚拟专用网络VPN服务
     * 
     * @param id 虚拟专用网络VPN服务主键
     * @return 虚拟专用网络VPN服务
     */
    @Override
    public VpnServices selectVpnServicesById(Integer id)
    {
        return vpnServicesMapper.selectVpnServicesById(id);
    }

    /**
     * 查询虚拟专用网络VPN服务列表
     * 
     * @param vpnServices 虚拟专用网络VPN服务
     * @return 虚拟专用网络VPN服务
     */
    @Override
    public List<VpnServices> selectVpnServicesList(VpnServices vpnServices)
    {
        return vpnServicesMapper.selectVpnServicesList(vpnServices);
    }

    /**
     * 新增虚拟专用网络VPN服务
     * 
     * @param vpnServices 虚拟专用网络VPN服务
     * @return 结果
     */
    @Override
    public int insertVpnServices(VpnServices vpnServices)
    {
        return vpnServicesMapper.insertVpnServices(vpnServices);
    }

    /**
     * 修改虚拟专用网络VPN服务
     * 
     * @param vpnServices 虚拟专用网络VPN服务
     * @return 结果
     */
    @Override
    public int updateVpnServices(VpnServices vpnServices)
    {
        return vpnServicesMapper.updateVpnServices(vpnServices);
    }

    /**
     * 批量删除虚拟专用网络VPN服务
     * 
     * @param ids 需要删除的虚拟专用网络VPN服务主键
     * @return 结果
     */
    @Override
    public int deleteVpnServicesByIds(Integer[] ids)
    {
        return vpnServicesMapper.deleteVpnServicesByIds(ids);
    }

    /**
     * 删除虚拟专用网络VPN服务信息
     * 
     * @param id 虚拟专用网络VPN服务主键
     * @return 结果
     */
    @Override
    public int deleteVpnServicesById(Integer id)
    {
        return vpnServicesMapper.deleteVpnServicesById(id);
    }
}
